<?php

/**
 * Register all actions and filters for the plugin
 *
 * @link  http://wpgenious.com/
 * @since 1.0.0
 *
 * @package    Wpgenious_Job_Listing
 * @subpackage Wpgenious_Job_Listing/includes
 */

/**
 * Register all actions and filters for the plugin.
 *
 * Maintain a list of all hooks that are registered throughout
 * the plugin, and register them with the WordPress API. Call the
 * run function to execute the list of actions and filters.
 *
 * @package    Wpgenious_Job_Listing
 * @subpackage Wpgenious_Job_Listing/includes
 * @author     wpgenious <contact@wpgenious.com>
 */
class Wpgenious_Job_Listing_Tools
{

    /**
     * Get applications count for specific job
     *
     * @param  $post_id
     * @return int
     */
    public static function get_applications_count($post_id)
    {
        return count(self::get_applications($post_id));
    }

    /**
     * @param  $post_id
     * @return int[]|WP_Post[]
     */
    public static function get_applications($post_id)
    {
        return get_children(
            array(
                'post_parent' => $post_id,
                'post_type'   => 'job_application',
                'numberposts' => -1,
                'orderby'     => 'date',
                'order'       => 'DESC',
                'fields'      => 'all',
            )
        );
    }

    /**
     * @param  $post_id
     * @return int|mixed
     */
    public static function get_job_views($post_id)
    {
        $views = get_post_meta($post_id, 'job_views_count', true);

        return $views ? $views : 0;
    }

    /**
     * @return string[]
     */
    public static function allowed_file_extensions()
    {
        return array('pdf', 'doc', 'docx');
    }

    /**
     * @param $job_id
     * @return bool
     */
    public static function is_expired_job($job_id) {
        $job_expiry_date = get_post_meta($job_id, 'job_expiry', true);

        if(empty($job_expiry_date)) {
            return false;
        }

        return  strtotime($job_expiry_date) < strtotime(date("Y-m-d"));
    }
}
