<?php
/**
 * Template for displaying single job listing content
 *
 * Override this by copying it to current-theme/wpgenious-job-listing/single-job_listing.php
 *
 * @link  http://wpgenious.com/
 * @since 1.0.0
 *
 * @package    Wpgenious_Job_Listing
 * @subpackage Wpgenious_Job_Listing/public/partials
 */

if (! defined('ABSPATH') ) {
    exit;
}

$fields = wpgenious_get_plugin_option('job_custom_fields') ? unserialize(wpgenious_get_plugin_option('job_custom_fields')) : [];
$no_job_found = wpgenious_get_plugin_option('default_msg_no_job_found');
$grid_cols = wpgenious_get_plugin_option('listing_grid_number_columns');

if(!isset($query) ) {
    $jobs_per_page = wpgenious_get_plugin_option('listing_jobs_per_page');

    $args = array(
        'post_type' => 'job_listing',
        'posts_per_page' => $jobs_per_page
    );

    if(!empty($url_params)) {
        foreach ($url_params as $key => $value) {
            if($key === 'keyword') {
                $args['s'] = $value;
            }else {
                $args['tax_query'][] = array(
                    'taxonomy' => $key,
                    'field' => 'term_id',
                    'terms' => $value,
                );
            }
        }
    }

    $query = new WP_Query($args);
}

$max_num_pages = $query->max_num_pages;
$paged = ( $query->query_vars['paged'] ) ? $query->query_vars['paged'] : 1;
$jobs = $query->posts;

?>

<?php if(count($jobs)) : ?>
    <?php foreach ($jobs as $job) : ?>
        <div class="wpgenious-job-listing-job-item wpgenious-job-listing-<?php echo $job->ID; ?> wpgenious-job-listing-grid-col-<?php echo $grid_cols; ?>">
            <div class="job-details">
                <div class="wpgenious-job-listing-job-left-part">
                    <h2 class="wpgenious-job-listing-job-title">
                        <a href="<?php echo esc_url($job->guid); ?>">
                            <?php echo esc_html($job->post_title); ?>
                        </a>
                    </h2>
                    <div class="wpgenious-job-listing-job-custom-fields">
                        <ul>
                            <?php foreach ($fields as $key => $field) : ?>
                                <?php $terms = get_the_terms($job->ID, $field['slug']); ?>
                                <?php if(!empty($terms) ) : ?>
                                    <li>
                                        <?php if(!empty($field['icon'])) : ?>
                                            <span class="<?php echo esc_html($field['icon']); ?>"></span>
                                        <?php else: ?>
                                            <span class="wpgenious-job-listing-job-custom-field-name">
                                                <strong>
                                                    <?php echo esc_html_e($field['name'], 'wpgenious-job-listing'); ?> :
                                                </strong>
                                            </span>
                                        <?php endif; ?>
                                        <?php foreach ($terms as $term) : ?>
                                            <span class="job-field job-field-<?php echo esc_html($term->slug); ?>"><?php echo esc_html($term->name); ?></span>
                                        <?php endforeach; ?>
                                    </li>
                                <?php endif; ?>
                            <?php endforeach; ?>
                        </ul>
                    </div>
                </div>
                <div class="wpgenious-job-listing-job-more-details">
                    <a class="wpgenious-job-listing-btn wpgenious-job-listing-job-more-details-link" href="<?php echo esc_url($job->guid); ?>">
                        <?php echo __('More Details', 'wpgenious-job-listing'); ?>
                    </a>
                </div>
            </div>
        </div>
    <?php endforeach; ?>
<?php else : ?>
    <div class="wpgenious-job-listing-no-job-found">
        <?php echo esc_html_e($no_job_found, 'wpgenious-job-listing'); ?>
    </div>
<?php endif; ?>
